##  Optional Extensions of the Data Model
It is possible to extend the standard Data Model with optional extensions such as through the [Tech Platform Fact Sheet](https://help.sap.com/docs/leanix/ea/tech-platform-fact-sheet-v3?locale=en-US&state=PRODUCTION&version=CLOUD) and Value Stream Fact Sheet (no longer offered to new customers).
